%-------- Calculation of cross sectional area in Surge Headbay -----------
%------------------by Bente Taraldsten Brunes ----------------------------

clc
clear all

tic
disp('Calculating...'); 

%------------------- Dimensions Ellipse at 885.2 masl -------------------- 
b0 = (22 + 4.216); 
a0 = ((2*21.863) + (b0*tan(pi*35/180)))/2;


%--------------- Dimensions of operating platform at 885.2 ---------------
t0 = b0 - 22.000;                   % width operating platform. 
l  = 2*44.234*tan(pi*7/180);        % length of blokcs
no = 5.5 ;                          % Number of blocks
a_0 = l*t0*no ;                     % Base area operating platform. 


%------------------------ Total Base Area --------------------------------
A_0(1,2) = pi*a0*b0 - a_0;
A_0(1,1) =  round((882.5)*10)/10;

% Writing the table
dlmwrite('crossection.xls', A_0, 'precision', 4)


%------- Cross-sectional Area from 882.6 to 905.6 masl -------------------

alpha = atan(1/5);          % Slope General section
beta = atan(1/7);           % Slope Operating platform

L = 905.6-882.6;            % Height of calculation area
Lop = 907-882.5;            % Height operating platform (OP)
m = L/0.1;
x = 0;

for i = 1:m                  %Expands a and b
  
  a1 = a0 + x*tan(alpha) ;
  b1 = b0 + x*tan(alpha) ;
  t_1 = (L - x)*tan(beta);
  t_2 =   x*tan(alpha);
  t = t_1 + t_2 ;               
  
  A(i,2) = pi*a1*b1 - l*t*no;      % Area of an ellipse subtract the OP
  A(i,1) = 882.6 + x;               
  x = x + 0.1;
  
end

dlmwrite('crossection.xls', A, 'precision', 4, '-append')



%--------------- Cross-sectional Area from 905.6 to 906.4 ----------------

n = (906.4 - 905.6)/0.1 + 1;
theta = atan( (0.514 - (907-905.6)*tan(beta))/(907-905.6));       
x = x + 0.1;
y = 0;

for j = 1:n                  %Expands a and b
    
  a2 = a0 + x*tan(alpha);
  b2 = b0 + x*tan(alpha) ;
  t2 = y*tan(theta) + x*tan(alpha) ;
   
  A_2(j,2) = pi*a2*b2 - l*t2*no;
  A_2(j,1) = 882.6 + x;
  x = x + 0.1;
  y = y + 0.1; 
  
end
 

dlmwrite('crossection.xls', A_2,'precision', 4, '-append')


%----------------------- From 906.5 to 907,0 ----------------------------

o = (907 - 906.5)/0.1 + 1; 

for k = 1:o                 %Expands a and b
  a3 = a0 + x*tan(alpha);
  b3 = b0 + x*tan(alpha) ;
  t3 = 5.4 ;
  
  A_3(k,2) = pi*a3*b3 - l*t3*no;
  A_3(k,1) = 882.6 + x;
 
  x = x + 0.1;
end

dlmwrite('crossection.xls', A_3,'precision', 4, '-append')


%---------------------- From 907.1 to 909.2 ------------------------------

p = (909.2 - 907.1)/0.1 + 1;

for g = 1:p                 %Expands a and b
  a4 = a0 + x*tan(alpha);
  b4 = b0 + x*tan(alpha) ;
  
  
  A_4(g,2) = pi*a4*b4 ;
  A_4(g,1) = 882.6 + x;
 
  x = x + 0.1;
end

dlmwrite('crossection.xls', A_4,'precision', 4, '-append')


%------------ From 909.3 to 909.7 -----------------------------------------
%------------------- Short approximation ----------------------------------
q = (909.7 - 909.3)/0.1 + 1;

for h = 1:q                 %Expands a and b
  a5 = a0 + (907.9 - 882.5)*tan(alpha);
  b5 = b0 + (907.9 - 882.5)*tan(alpha);
    
  A_5(h,2) = pi*a5*b5;
  A_5(h,1) = 882.6 + x;
 
  x = x + 0.1;
end

dlmwrite('crossection.xls', A_5,'precision', 4, '-append')

toc
