%-------------- Reduction in head program ------------------------

clear all
clc

H0 = 902.7;  
Hv = 764;             % Elevation of turbine, reference
Qn = 68;
Pn = 82;
tmax = 1300;
c_1  = 5.2e-5 ;             % Headloss coefficient
c_2 = 6.15e-4;
c_s = 0.00001;              % Assumed value

eta = 0.94;
rho = 997;
g   = 9.781 ;               % Gravity [m/s^2]

Q2(1,1) = 68;
Q1(1,1) = Q2(1,1)*4;

hf(1,1) = c_1*Q1(1,1)^2 + c_2*Q2(1,1)^2 + 0.4e-4*Q2(1,1)^2;
k = hf(1)*Q2(1,1)^2/(Qn^2);
Hnew(1,1) = H0 - k ;
Pnew(1,1) = rho*g*Q2(1,1)*(Hnew(1,1)-Hv)*10^(-6);

for t = 2:tmax
    Q_s1(t,1) =  Q1(t-1,1) - Q2(t-1,1);
   
    hf(t-1,1) = c_1*Q1(t-1,1)^2 + c_2*Q2(t-1,1)^2 + 0.4e-4*Q2(t-1,1)^2;
    k = hf(t-1)*Q2(t-1,1)^2/(Qn^2);
    Hnew(t,1) = H0 - k ;
    Pnew(t,1) = rho*g*Q2(t-1,1)*(Hnew(t-1,1)-Hv)*10^(-6);
    
    Q1(t,1) = Q1(t-1,1)+ 0.1;
    Q2(t,1) = Q1(t-1,1)/4 + 0.1;
    
    
end

Hnew = Hnew - Hv;
P93  = ((Pnew*0.93/Pn)-1)*100;
P94  = ((Pnew*0.94/Pn)-1)*100;
P95  = ((Pnew*0.95/Pn)-1)*100;

figure(1)
hold on

clf
grid on

hl1 = line(Q2,Hnew,'Color','b', 'LineWidth', 4);
line([85 85], [105 135], 'LineStyle','-.', 'LineWidth', 3 , 'Color', 'k')
text(85.5,106, 'max volume flow','VerticalAlignment', 'baseline' ...
    , 'Fontsize', 18)
ax1 = gca;
set(ax1, 'XColor','k','YColor','k', 'Fontsize', 24, 'Color', 'w')

ylabel('H_e [m]', 'Fontsize', 30 )
xlabel('Volume flow 1 unit [m^3/s]', 'Fontsize', 30 )

% ax2 = axes('Position',get(ax1,'Position'),'XAxisLocation','bottom',...
%            'YAxisLocation','right', 'Color','none','XColor','k', ...
%            'YColor','k','Fontsize', 24);
% ylabel('Potential increase in power output [%]', 'Fontsize', 30 )
% 
% hl2 = line(Q2,P93,'Color','r','Parent',ax2, 'LineWidth', 3);
% text(100.7,17.6, '\eta_t = 0.93', 'Fontsize', 18)
% hl3 = line(Q2,P94,'Color','g','Parent',ax2, 'LineWidth', 3);
% text(100.7,19, '\eta_t = 0.94', 'Fontsize', 18)
% hl4 = line(Q2,P95,'Color','m','Parent',ax2, 'LineWidth', 3);
% text(100.7,20.4, '\eta_t = 0.95', 'Fontsize', 18)
% text(83.25,14.73, 'o','HorizontalAlignment','center','Fontsize', 18)
% text(83.25,15.95, 'o','HorizontalAlignment','center','Fontsize', 18)
% text(83.25,13.51, 'o','HorizontalAlignment','center','Fontsize', 18)

hold off
