%--------------------  OSCILLIATION ENTIRE SYSTEM -------------------------
clear all
clc

tic
disp('calculating');

%------------------------ PARAMETERES -------------------------------------

H_0 = 904.5;               % Normal water level in diversion weir
g   = 9.781 ;               % Gravity [m/s^2]
c_s = 0.00001;              % Assumed value
Hv = 756.2;             % Elevation of turbine, reference

%Pressure tunnel 1.1
L_t1 = 1215 ;               % Length [m]
D_t1 = 8.3  ;               % Diameter [m]
A_t1 = (pi/4)*D_t1^2 ;      % Area [m^2]

%Pressure tunnel 1.2 
L_t2 = 285 ;                % Length [m]
D_t2 = 7.4 ;                % Diameter [m]
A_t2 = (pi/4)*D_t2^2 ;      % Area [m^2]

%Average pressure tunnel 1
L_1 = L_t1 + L_t2  ;                             % Length [m]
A_1  =  (L_t1*A_t1 + L_t2*A_t2)/(L_t1+L_t2); % Area [m^2]
c_1  = 5.2e-5 ;                             % Headloss coefficient

% Penstock, tunnel 2
L_2 = 182.1 ;
D_2 = 3.6 ;
A_2 = (pi/4)*D_2^2;
np  = 4;                                    % Number of penstocks
c_2 = 6.15e-4;

% Surge Chamber

A2_s = [765 40000; 766 40000; 767 40000; 768 40000; 769 816; 770 802; ...
        771 768; 772 850; 773 802; 774 789; 775 782 ];
    %Tailrace tunnel roof is at 769, areas below are therefore LARGE.... 
    %Read from drawing
    
% Tailrace, tunnel 3
L_3 = 675 ;
w_3  = 11;                  % Width of tunnel
h_3 = 13.9;                 % Height
A_3 = w_3*h_3 ;
H_u = 768.3;               % Water level in Tailrace
c_3 = 0.4e-4;

%------------READING CROSSECTION AREA FOR SURGE HEADBAY MATRIX----------

A_surgelevel = dlmread('crossection.xls');


%----------------- INITIAL VALUES AT t=0 s -----------------------------
Q0           = 3*71;
Q_1(1,1)     = Q0;                     % Volume flow in pressure tunnel (1)
Q_2(1,1)     = 284;                     % Volume flow in penstock (2)
Q_3(1,1)     = Q0;                     % Volume flow in tailrace (3)
z1(1,1)      = H_0 - c_1*Q0*abs(Q0);   % Initial level in Surge Headbay
z2(1,1)      = H_u ;%Q0*0.003+ 762.4;        % Initial level in Surge Chamber
Q_s1(1,1)    = 0;                      % Volume flow into Surge Headbay
Q_s2(1,1)    = 0;                      % Volume flow into Surge Chamber
Hn           = 130.2;                  % Design head
Qn           = 284;                    % Design flow
dt           = 0.1;                    % Time step
tmax         = 7000;                   % Maximum calculation time 

kappa(1,1) = 1;
y =1;
l=1;
%--------------------- Surge Oscilliation ------------------------------
%%
n = 4648;   %Second interception point with stationary pressure line
o = n + 26;
p = 6659;   % Third interception point with stationary pressure line
q = p + 18;
r = 6368;
s = r + 18;
u = 6800;
v = u + 18;

for t = 2: tmax     
      
    if t< 70               %Determines the opening degree of the turbine
       kappa(t,1)= 1 - t*0.01329;
%     elseif t<n
%        kappa(t,1) = 0.07;
%     elseif t>=n && t < o             
%        kappa(t,1) = 0.07 + 0.01*(t-n);   %Reloading one turbine
%     elseif t>= o && t< p
%         kappa(t,1) = 0.25;
%     elseif t>=p && t< q
%         kappa(t,1) = 0.25 - 0.01*(t-p);  
%     elseif t>=q && t < r             
%       kappa(t,1) = 0.07;
%     elseif t>= r && t< s
%         kappa(t,1) = 0.07 + 0.01*(t-r);   %Reloading one turbine
%     elseif t >=s && t< u
%         kappa(t,1) = 0.25;
%     elseif t>=u && t< v
%         kappa(t,1) = 0.25 - 0.01*(t-u);  
    else
        kappa(t,1) = 0.07;
    end

    z1s  = round(z1(t-1,1)*10)/10 ;          %Round off to one decimal
    
    % Finds the crossectional area corresponding to the surge level
    %  in the Surge Headbay
     
    for i = 1:length(A_surgelevel)   
        x = A_surgelevel(i,1);             
         if x == z1s
            y = i;
         end         
    end
    
%     Finds the crossectional area corresponding to the surge level in 
%     the Surge Chamber
    
     z2s(t-1,1)  = round(z2(t-1,1));  %Round off to zero decimal
         for j = 1:length(A2_s)        
            k = A2_s(j,1);           
            if k == z2s(t-1,1)
            l = j;
            end         
         end 
     
    As1 = A_surgelevel(y,2);
    As2 = A2_s(l,2);
    
    Q_s1(t-1,1) =  Q_1(t-1,1) - Q_2(t-1,1);
    Q_s2(t-1,1) =  Q_2(t-1,1) - Q_3(t-1,1);
   
    hf_1(t-1,1) = c_1*Q_1(t-1,1)*abs(Q_1(t-1,1));   
    hf_s1(t-1,1) = c_s*Q_s1(t-1,1)*abs(Q_s1(t-1,1));
    hf_2(t-1,1) = c_2*Q_2(t-1,1)*abs(Q_2(t-1,1));
    hf_s2(t-1,1) = c_s*Q_s2(t-1,1)*abs(Q_s2(t-1,1));
    hf_3(t-1,1) = c_1*Q_3(t-1,1)*abs(Q_3(t-1,1));
    
    Q_1(t,1)  = Q_1(t-1,1) + (g*dt*A_1/L_1)*(H_0 - z1(t-1,1) ...
                - (hf_1(t-1,1) + hf_s1(t-1,1)));
           
    Q_2(t,1) = Q_2(t-1,1) + (g*dt*A_2/L_2)*(z1(t-1,1) - z2(t-1,1) ...
                - Hn*(Q_2(t-1,1)/(kappa(t-1,1)*Q0))^2 - hf_2(t-1,1));
         
    Q_3(t,1)  = Q_3(t-1,1) + (g*dt*A_3/L_3)*(z2(t-1,1) - H_u ...
                - (hf_3(t-1,1) + hf_s2(t-1,1)));
     
    z1(t,1) =  z1(t-1,1) + (dt/As1)*(Q_1(t-1,1) - Q_2(t-1,1));
    
    z2(t,1)  = z2(t-1,1) + 10*(dt/As2)*(Q_2(t-1,1) - Q_3(t-1,1));
    
    hf = hf_1 + hf_2/4;
    
    Hnew = H_0 - hf*Q_1(t,1)^2/(Qn^2);
        
end

%%
Q_s1(tmax,1) = Q_1(tmax,1)-Q_2(tmax,1);        

H0 = zeros(length(z1),1)+ H_0;
H_air = zeros(length(z1),1)+891.5; 
Hmax = zeros(length(z1),1)+ 909.7; 
Hplatform = zeros(length(z1),1)+ 907; 
Hu = zeros(length(z1),1)+ H_u;
Hs2top = zeros(length(z1),1) + 775; 
Hs2tunnelroof = zeros(length(z1),1) + 768.5; 
t = transpose(1:(length(z1)));

kplot = kappa;
tplot = t*dt;
%Surge Oscilliation in Surge Headbay figure

figure(1)
clf
hold on
grid on

hl1 = line(tplot,z1,'Color','b', 'LineWidth', 4);
ax1 = gca;
set(ax1, 'XColor','k','YColor','k', 'Fontsize', 24, 'Color', 'w')
ylabel('Oscilliation level in Surge Headbay', 'Fontsize', 30 )
xlabel('time [s]', 'Fontsize', 30 )

hl2 = line(tplot, H0, 'LineStyle', '--', 'Color', 'k','LineWidth', 3); 
hl3 = line(tplot, H_air, 'LineStyle', '--', 'Color', 'c','LineWidth', 3);
hl4 = line(tplot, Hmax, 'LineStyle', '--', 'Color', 'm','LineWidth', 3);
hl5 = line (tplot, Hplatform, 'LineStyle', '--', 'Color', ...
                'g','LineWidth', 3);
legend('Oscilliation Level','H_0','Air suction level',...
    'Max level','Operating Platform Level', ...
    'Location','NorthEast')

ax2 = axes('Position',get(ax1,'Position'),'XAxisLocation','bottom',...
           'YAxisLocation','right', 'Color','none','XColor','k', ...
           'YColor','k','Fontsize', 24);
hl6 = line(tplot,kplot,'Color','r','Parent',ax2, 'LineWidth', 2);


legend('Admissions degree', 'Location','NorthEast')

hold off

%Surge Oscilliation in Surge Chamber figure
tplot2 = tplot*10;
figure(2)
clf
hold on
grid on

hl7 = line(tplot2,z2,'Color','b', 'LineWidth', 4);
ax3 = gca;
set(ax3, 'XColor','k','YColor','k', 'Fontsize', 24, 'Color', 'w');
ylabel('Oscilliation level in Surge Chamber [m]', 'Fontsize', 30 )
xlabel('time [s]', 'Fontsize', 30 )

hl8 = line(tplot2, Hs2top, 'LineStyle', '--', 'Color', ...
        'g','LineWidth', 4); 
hl9 = line(tplot2, Hs2tunnelroof, 'LineStyle', '--', 'Color', 'c', ...
        'LineWidth', 3);
hl10 = line(tplot2, Hu, 'LineStyle', '--', 'Color', 'k','LineWidth', 3);
legend('Oscilliation Level','Max level in Surge Chamber', ...
    'Tailrace tunnel roof','H_u', 'Location','NorthEast')

ax4 = axes('Position',get(ax3,'Position'),'XAxisLocation','bottom',...
           'YAxisLocation','right', 'Color','none','XColor','k', ...
           'YColor','k','Fontsize', 24);

hl11 = line(tplot2,kplot,'Color','r','Parent',ax4, 'LineWidth', 3);
legend('Admission degree turbine ', 'Location','NorthEast')
hold off


toc