clear all
clc
tic
disp('calculating');

%---------------- PARAMETERS --------------

Hv = 756.2;             % Elevation of turbine, reference
g   = 9.781 ;           % Gravity [m/s^2]

% Penstock
tunnel.L = 180 ;
tunnel.D = 3.6 ;
tunnel.A = (pi/4)*tunnel.D^2;
tunnel.np  = 4;                                    
tunnel.c = 0.000615;

%-------------READING CROSSECTION AREA FOR SURGE HEADBAY MATRIX----------

A_surgelevel = dlmread('crossection.xls');


%-----------------------------------------------------------------------

L = tunnel.L;

a  = 1200;
dx = 5;
dt = dx/a;

x0 = dx;
Q0  = 86;
tmax = 2500;
x = x0;
l = 1;
y = 1;
Qn = Q0;

Z(1) = 904.5;              % Maximum surge level in SH.
B = a/(g*tunnel.A);
R = tunnel.c;

Tl= round(5/dt);           % Closing time turbine
k = (1-1e-7)/Tl;
%---------------------------
  
for t = 1:1:tmax
    
 for x = x0:dx:L    % Storing inital values at t=0
    Q(x,t) = Q0;
    H(x,t) = Z(1);

 end
end



%%
kappa = 1;

for n = 1:1:tmax
    if n <Tl
       kappa = kappa - k;
    else 
       kappa = 1e-7;
    end
    K(n,1) = kappa;
    
    for x = x0:dx:L
       if n == 1          %Inital values at t = 1
            Q(x,n) = Q0;
            if x == x0;
                H(x,n) = Z(1);
            else
                H(x,n) = H(x-dx,n) - R*Q(x-dx,n)*abs(Q(x-dx,n));
            end
            
            Hn   = H(L,1);
       
        elseif x == x0
            z1s  = round(Z(n-1)*10)/10 ;   %Round off to one decimal
    
                for i = 1:length(A_surgelevel)   
                 l = A_surgelevel(i,1);             
                    if l == z1s
                    y = i;
                    end         
                end 
 
            As = A_surgelevel(y,2);
            
            Z(n)   = Z(n-1) + dt*Q(x,n-1)/As;
            H(x,n) = Z(n);
            Cb     = H(x+dx,n-1) + R*Q(x+dx,n-1)*abs(Q(x+dx,n-1));
            Q(x,n) = (1/B)*(H(x,n) - Cb) + Q(x+dx,n-1);

         elseif x>x0 && x<L 
            Ca     = H(x-dx,n-1) - R*Q(x-dx,n-1)*abs(Q(x-dx,n-1));
            Cb     = H(x+dx,n-1) + R*Q(x+dx,n-1)*abs(Q(x+dx,n-1));
            Qr     = Q(x+dx,n-1) - Q(x-dx,n-1);  
            H(x,n) = 0.5*(Ca + Cb - B*Qr);
            Q(x,n) = (1/B)*(H(x,n) - Cb) + Q(x+dx,n-1);
                       
         elseif x == L 
            
            Cv = ((kappa*Qn)^2)/Hn;
            Ca = H(x-dx,n-1) + B*Q(x-dx,n-1) - ...
                R*Q(x-dx,n-1)*abs(Q(x-dx,n-1));
            Q(x,n) = -B*Cv*0.5 + 0.5*sqrt((B*Cv)^2 + 4*Cv*Ca);
            H(x,n) = (Q(x,n)/(kappa*Qn))^2*Hn;  
         end        
    end
end

%%


Hplot = H(L,:)-Hv;
Kplot = K;


t1 = 1:1:tmax;
tplot = t1*dt;
figure(1)
clf
hold on
grid on

hl1 = line(tplot,Hplot,'LineStyle', '-','Color','b', 'LineWidth', 4);
ax1 = gca;
set(ax1, 'XColor','k','YColor','k', 'Fontsize', 24, 'Color', 'w')
ylabel('Head at valve [mWC]', 'Fontsize', 30)
xlabel('time [s]', 'Fontsize', 30 )
legend('Pressure ',  'Location','SouthWest')

% ax2 = axes('Position',get(ax1,'Position'),'XAxisLocation','bottom',...
%            'YAxisLocation','right', 'Color','none','XColor','k', ...
%            'YColor','k','Fontsize', 24);
% 
% hl2 = line(tplot,Kplot,'Color','r','Parent',ax2, 'LineWidth', 2);
% ylabel('', 'Fontsize', 30 )
% 
% legend('Degree of admission',  'Location','SouthEast')

hold off


toc

 
